@@ -137,7 +137,7 @@ pub fn main() -> GameResult {
         .filter(Some("ggez"), log::LevelFilter::Warn);
     logger.init();
 
-    let mut cb = ggez::ContextBuilder::new("H1V3", "ljedrz").modules(ModuleConf {
+    let mut cb = ggez::ContextBuilder::new("h1v3", "ljedrz").modules(ModuleConf {
         gamepad: false,
         audio: false,
     });
@@ -157,7 +157,7 @@ pub fn main() -> GameResult {
         ..Default::default()
     };
     graphics::set_mode(&mut ctx, window_mode)?;
-    graphics::set_window_title(&ctx, "H1V3");
+    graphics::set_window_title(&ctx, "h1v3");
 
     let mut state = MainState::default();
     load_assets(&mut state, &mut ctx)?;
