@@ -1,5 +1,5 @@
 use ggez::Context;
-use h1v3_logic::{edge_index_non_tip, is_at_ring_tip, ring, ring_offset, tip_index, Position};
+use h1v3_logic::{is_at_ring_tip, ring, ring_edge_index, ring_offset, ring_tip_index, Position};
 
 use super::{consts::*, MainState};
 
@@ -11,7 +11,7 @@ pub fn position_to_point(pos: Position, r: f32, center: (f32, f32)) -> (f32, f32
     let ring = ring(pos);
 
     if is_at_ring_tip(pos) {
-        let tip_idx = tip_index(pos);
+        let tip_idx = ring_tip_index(pos);
         let ring = ring as f32;
 
         let (xm, ym) = match tip_idx {
@@ -28,7 +28,7 @@ pub fn position_to_point(pos: Position, r: f32, center: (f32, f32)) -> (f32, f32
 
         (center.0 + x, center.1 + y)
     } else {
-        let edge_idx = edge_index_non_tip(pos);
+        let edge_idx = ring_edge_index(pos);
         let ring_offset = ring_offset(ring);
         let ring_pos = pos - ring_offset;
         let tip_offset = ring_pos - edge_idx * ring;
